#!/usr/bin/env python3
"""
MCP-A2A-Gateway entry point for module execution.

This allows the package to be run as a module with:
    python -m mcp_a2a_gateway
    uvx run MCP-A2A-Gateway
"""

from mcp_a2a_gateway.main import main

if __name__ == "__main__":
    main()
